
#===== ex8.py =====
# Molecular dynamics for a polymer/cluster

import os
import numpy as np

#import init.py which contains functions for generating initial conditions
import Init

#import EMin.py which contains functions for energy/force calculations and minimizations
import Ecalc13

# import atomwrite.py which contains functions for writing pdb files
import Atomwrite

#=================== Global Variables used in main module ========================
#number of atoms in the polymer
Np = 30
#number of monomer atoms "silvers"
Ns = 0
#dimensions of the box
#L = ((Np+Ns)*10)**(1./3.)
L = 30.
#number of minimizations
Nmin = 10000

#=================== Global Variables used by other modules====================
# Variables for Emin.py:

# Epsilons and Sigmas for the LJ potential
EpsPP = 100.0

IsReduced = True

if IsReduced:
	EpsSS = 1.0
else:
	EpsSS = 0.01

EpsSP = 100.0

SigPP = 1.0
SigSS = 1.0
SigSP = 1.0

# distance cutoff for Lennard-Jones pairwise interactions
Cut = 2.5
# distance cutoff for counting "bound" atoms
CountCut = 2.5
# Number of spatial dimensions
Dim = 3
# fractional energy tolerance for line search
EFracTolLS = 1.e-8
# fractional energy tolerance for conjugate gradient search
EFracTolCG = 1.e-10
# initial step amount for LS and CG
dx = 0.001

EParams = [Np, Ns, L, Cut, EpsPP, EpsSS, EpsSP, SigPP, SigSS, SigSP, Dim]

# Temperature
T = 1.

# time step
dt = 0.0001

# total time for Molecular dyanmics run
tTot = 50.

# Number of steps before recentering and implying periodic boundary conditions
RescaleFreq = 10

# Number of steps between PDB files
WritePdbFreq = 700

# Number of steps between counting number of S bound to polymer
CountSPFreq = 100

#==================== Main module ============================

# Create a linear polymer
"""
PosPInit = np.zeros([Np,3])
for i in range(Np):
	PosPInit[i] = [0, i, 0]
#PosPInit = Init.InitPositionsRandom(Np, L)
if Ns == 0:
	Pos = PosPInit
"""
# make the center of mass at the origin
"""
if Np > 0.:
	PosPInit = Init.Center(PosPInit, Np)
"""
# Create a cluster or introduce random S-atoms
#FileName = "%iAg.pdb" %Ns
#PosSInit = Atomwrite.ReadPdb(FileName)
"""
PosSInit = Init.InitPositionsRandom(Ns, L)
if Ns > 0.:
	PosSInit[0,:] = PosSInit[0,:] - L/2.
	PosSInit[2,:] = PosSInit[0,:] - L/2.
	Pos = np.concatenate((PosPInit, PosSInit))
	# Make sure none of the S-atoms are too close to the P-atoms
	IfRelaxed = False
	while IfRelaxed == False:
		#Pos = Init.CenterP(Pos, Np, Ns)
		#Pos = Ecalc13.PeriodicBound(Pos, Np, Ns, L)
		(Pos, IfRelaxed) = Init.Relax(Pos, Np, Ns, L, IfRelaxed = True)
		
		#Pos[0:Np,:] = Init.Center(Pos[0:Np,:],Np)
		#Pos[Np:Np+Ns,:] = Init.Center(Pos[Np:Np+Ns,:],Ns)
#Pos = Init.CenterP(Pos, Np, Ns)
#Pos = Ecalc13.PeriodicBound(Pos, Np, Ns, L)
#Pos = Atomwrite.ReadPdb("AA1.pdb")
#print Pos
"""
# Create a polymer-wrapped cluster from file

Filename = "AAB.pdb"
Pos = Atomwrite.ReadPdb(Filename)

# Create atom names - these will be used to create 2-color pdb files
AtomNamesP = ["C"]
AtomNamesS = ["N"]

First = True
Atomwrite.WritePdb("AAA.pdb", Pos, Np, Ns, AtomNamesP, AtomNamesS, First)


Forces = np.zeros_like(Pos)
Vel = Ecalc13.InitVelocities(Np+Ns, T)
Vel[0,:] = 0.
(PEnergy, Forces) = Ecalc13.CalcEnergyForces(Pos, Vel, Forces, EParams, T, dt)
t = 0
print "%-8.6f" % t + "\t" + "%-8.6f" % PEnergy


Accel = Forces
(Pos, Vel) = Ecalc13.VVerlet(Pos, Vel, Accel, tTot, dt, RescaleFreq, CountSPFreq, CountCut, WritePdbFreq, EParams, T)
#Atomwrite.WritePdb("AAB.pdb", Pos, Np, Ns, AtomNamesP, AtomNamesS, First)